Learn R Programming

RProtoBuf (version 0.4.3)

FileDescriptor-class: Class "FileDescriptor"

Description

Class "FileDescriptor"

Arguments

Objects from the Class

Objects are usually created using the fileDescriptor method

Slots

pointer:
external pointer to a google::protobuf::FileDescriptor C++ object
package:
the package name defined in the file, e.g. 'tutorial'.
filename:
the filename of this FileDescriptor

Methods

$
signature(x = "FileDescriptor"): used to invoke a pseudo method of the file descriptor or get a top level message, enum or service descriptor
toString
signature(x = "FileDescriptor" ) : gets the debug string
as.character
signature(x = "FileDescriptor" ) : gets the debug string
show
signature(x = "FileDescriptor" ) : prints small text
name
signature(object = "FileDescriptor" ) : name of the file

References

The http://code.google.com/apis/protocolbuffers/docs/reference/cpp/google.protobuf.descriptor.html#FileDescriptor

See Also

Descriptor

Examples

Run this code
# example proto file supplied with this package
desc <- P("tutorial.Person")
person <- new(desc)

person$fileDescriptor()
name(person$fileDescriptor())
# [1] "addressbook.proto"
as.character(person$fileDescriptor())

Run the code above in your browser using DataLab