Learn R Programming

RProtoBuf (version 0.4.3)

FileInputStream-class: Class "FileInputStream"

Description

A ZeroCopyInputStream reading from a file

Arguments

Objects from the Class

Objects can be created by the FileInputStream function

Slots

pointer:
External pointer to the google::protobuf::io::FileInputStream C++ object

Extends

Class "ZeroCopyInputStream", directly.

Methods

close
signature(con="FileInputStream"): Flushes any buffers and closes the underlying file. Returns false if an error occurs during the process; use GetErrno to examine the error
GetErrno
signature(object="FileInputStream"): If an I/O error has occurred on this file descriptor, this is the errno from that error. Otherwise, this is zero. Once an error occurs, the stream is broken and all subsequent operations will fail.
SetCloseOnDelete
signature(object="FileInputStream"): set the close on delete behavior.
See ZeroCopyInputStream for inherited methods

References

The FileInputStream class from the protobuf C++ library. http://code.google.com/apis/protocolbuffers/docs/reference/cpp/google.protobuf.io.zero_copy_stream_impl_lite.html#FileInputStream

See Also

ZeroCopyInputStream for methods