Learn R Programming

RProtoBuf (version 0.4.3)

ZeroCopyOutputStream-class: Virtual Class "ZeroCopyOutputStream"

Description

R wrapper for the ZeroCopyOutputStream c++ class

Arguments

Objects from the Class

This is a virtual class

Slots

pointer:
external pointer to the google::protobuf::io::ZeroCopyOutputStream object

Methods

$
signature(x="ZeroCopyOutputStream"): invokes a method
Next
signature(object="ZeroCopyOutputStream", payload = "raw" ): push the raw vector into the stream. Returns the number of bytes actually written.
BackUp
signature(object="ZeroCopyOutputStream"): Backs up a number of bytes, so that the end of the last buffer returned by Next is not actually written.
ByteCount
signature(object="ZeroCopyOutputStream"): Returns the total number of bytes written since this object was created.
WriteRaw
signature(object="ZeroCopyOuputStream", payload = "raw": write the raw bytes to the stream

References

The google::protobuf::io::ZeroCopyOutputStream C++ class. http://code.google.com/apis/protocolbuffers/docs/reference/cpp/google.protobuf.io.zero_copy_stream.html#ZeroCopyOutputStream

See Also

TODO: add classes that extend