enum_type: Extract an enum type descriptor for a nested type

enum_type-methodsR Documentation

Extract an enum type descriptor for a nested type

Description

Extract a EnumDescriptor contained in a Descriptor

See Also

The method is implemented for the Descriptor class


RProtoBuf documentation built on March 7, 2026, 9:07 a.m.