nested_type: Extract a message type descriptor for a nested type

nested_type-methodsR Documentation

Extract a message type descriptor for a nested type

Description

Extract a Descriptor nested in another Descriptor

See Also

The method is implemented for the Descriptor class


RProtoBuf documentation built on March 7, 2026, 9:07 a.m.