Rdocumentation
powered by
Learn R Programming
RProtoBuf (version 0.4.3)
swap-methods: swap elements of a repeated field of a message
Description
swap elements of a repeated field of a message.
Arguments
Methods
signature(object = "Message")
swap elements of a repeated field of a message
References
See the
SwapElements
of the
Reflection
class, part of the protobuf library.
http://code.google.com/apis/protocolbuffers/docs/reference/cpp/google.protobuf.message.html