FileOutputStream-class: Class "FileOutputStream"
Description
A ZeroCopyOutputStream reading from a fileSlots
pointer:- External pointer to the
google::protobuf::io::FileOutputStream C++ object
Extends
Class "ZeroCopyOutputStream", directly.Methods
- close
signature(con="FileOutputStream"):
Flushes any buffers and closes the underlying file.
Returns false if an error occurs during the process; use GetErrno to examine the error
- flush
signature(con="FileOutputStream"):
Flushes FileOutputStream's buffers but does not close the underlying file
- GetErrno
signature(object="FileInputStream"):
If an I/O error has occurred on this file descriptor, this is the errno from that error.
Otherwise, this is zero. Once an error occurs, the stream is broken and all subsequent operations will fail.
- SetCloseOnDelete
signature(object="FileOutputStream"):
set the close on delete behavior.
See ZeroCopyOutputStream for inherited methodsSee Also
ZeroCopyOutputStream for methods