MethodDescriptor-class: Class "MethodDescriptor"
Description
R representation of Service DescriptorsObjects from the Class
TODOSlots
pointer:- External pointer to a
google::protobuf::MethodDescriptor C++ object name:- fully qualified name of the method
service:- fully qualified name of the servive that defines this method
Methods
- as.character
signature(x = "MethodDescriptor"): debug string of the method - toString
signature(x = "MethodDescriptor"): debug string of the method - $
signature(x = "MethodDescriptor"): ... - $<-
signature(x = "MethodDescriptor"): ... - input_type
signature(object = "MethodDescriptor"): the Descriptor of the input type of the method - output_type
signature(object = "MethodDescriptor"): the Descriptor of the output type of the method