ZeroCopyInputStream-class: Virtual Class "ZeroCopyInputStream"
Description
R wrapper for the ZeroCopyInputStream c++ classObjects from the Class
This is a virtual classSlots
pointer:- external pointer to the
google::protobuf::io::ZeroCopyInputStream object
Methods
- $
signature(x="ZeroCopyInputStream"): invokes a method - Next
signature(object="ZeroCopyInputStream"): Get a number of bytes from the stream as a raw vector. - Skip
signature(object="ZeroCopyInputStream"): skip a number of bytes - BackUp
signature(object="ZeroCopyInputStream"): Backs up a number of bytes, so that the next call to Next returns data again that was already returned by the last call to Next. - ByteCount
signature(object="ZeroCopyInputStream"): Returns the total number of bytes read since this object was created. - ReadRaw
signature(object="ZeroCopyInputStream", size = "integer"): read raw bytes from the stream - ReadRaw
signature(object="ZeroCopyInputStream", size = "numeric"): read raw bytes from the stream - ReadString
signature(object="ZeroCopyInputStream", size = "integer"): same as ReadRaw but formats the result as a string - ReadString
signature(object="ZeroCopyInputStream", size = "numeric"): same as ReadRaw but formats the result as a string - ReadVarint32
signature(object="ZeroCopyInputStream"): Read an unsigned integer with Varint encoding, truncating to 32 bits. - ReadLittleEndian32
signature(object="ZeroCopyInputStream"): Read a 32-bit little-endian integer. - ReadLittleEndian64
signature(object="ZeroCopyInputStream"): Read a 64-bit little-endian integer. In R the value is stored as a double which looses some precision (no other way) - ReadVarint64
signature(object="ZeroCopyInputStream"): Read a 64-bit integer with varint encoding. In R the value is stored as a double which looses some precision (no other way)
See Also
TODO: add classes that extend