ZeroCopyOutputStream-class: Virtual Class "ZeroCopyOutputStream"
Description
R wrapper for the ZeroCopyOutputStream c++ classObjects from the Class
This is a virtual classSlots
pointer:- external pointer to the
google::protobuf::io::ZeroCopyOutputStream object
Methods
- $
signature(x="ZeroCopyOutputStream"): invokes a method - Next
signature(object="ZeroCopyOutputStream", payload = "raw" ): push the raw vector into the stream. Returns the number of bytes actually written. - BackUp
signature(object="ZeroCopyOutputStream"): Backs up a number of bytes, so that the end of the last buffer returned by Next is not actually written. - ByteCount
signature(object="ZeroCopyOutputStream"): Returns the total number of bytes written since this object was created. - WriteRaw
signature(object="ZeroCopyOuputStream", payload = "raw": write the raw bytes to the stream
See Also
TODO: add classes that extend